<?php declare(strict_types=1);

namespace EuKit\Base\Services;

use EuKit\Base\Interfaces\ThemeServiceStartup;
use Infomaker\Imengine\Imengine;
use OpenContent;

/**
 * Class ImengineServiceStartup
 * @package EuKit\Base\Services
 */
class ImengineServiceStartup implements ThemeServiceStartup
{

    /**
     * Map to default value set by the OpenContent plugin
     *
     * @see everyware/includes/open_content.php
     */
    private const OPEN_CONTENT_DEFAULT_URL = 'http://example.imengine.com/image.php';

    /**
     * Map to default value set by the Everyware plugin
     *
     * @see everyware/includes/open_content.php
     */
    private const IMENGINE = 'imengine';

    /**
     * @var OpenContent
     */
    private $openContent;
    /**
     * @var string
     */
    private $definedUrl;

    public function __construct(OpenContent $openContent)
    {
        $this->openContent = $openContent;
    }

    public function setup(): void
    {
        if ($this->openContent->getImageService() === static::IMENGINE) {
            $this->setupImengine();
        }
    }

    public function getServiceUrl(): string
    {
        return $this->definedUrl;
    }

    private function setupImengine(): void
    {
        $this->definedUrl = $this->openContent->getImengineUrl();

        if (empty($this->definedUrl) || $this->definedUrl === static::OPEN_CONTENT_DEFAULT_URL) {
            $this->definedUrl = \defined('CF_IMENGINE') ? CF_IMENGINE : '';
        }

        Imengine::setup($this->definedUrl);
    }
}
